From f9e05bc334cd06606afa3322f267f98e4467e7ec Mon Sep 17 00:00:00 2001
From: Nicholas Esterer <nicholas.esterer@plot.ly>
Date: Thu, 2 Jul 2020 18:15:05 -0400
Subject: [PATCH] handle case where axis id is undefined

however there's a funny case when running
./test/image/mocks/sunburst_with-without_values.json where
xAx (local function) gets passed an array in
./src/components/shapes/defaults.js (it expects a string or undefined).
So we still need to solve this.
---
 .gitignore                        | 1 +
 src/components/shapes/defaults.js | 8 ++++++--
 src/plots/cartesian/axis_ids.js   | 2 +-
 3 files changed, 8 insertions(+), 3 deletions(-)

diff --git a/.gitignore b/.gitignore
index 2316129015e..f4c03139eec 100644
--- a/.gitignore
+++ b/.gitignore
@@ -7,6 +7,7 @@ build/*
 npm-debug.log*
 *.sublime*
 *~
+tags
 
 .*
 !.circleci
diff --git a/src/components/shapes/defaults.js b/src/components/shapes/defaults.js
index bbb18737d2a..331d41889df 100644
--- a/src/components/shapes/defaults.js
+++ b/src/components/shapes/defaults.js
@@ -64,11 +64,15 @@ function handleShapeDefaults(shapeIn, shapeOut, fullLayout) {
         var coerceRefExtras=['paper'];
         // extract axis if domain specified
         var xAx = function (ar) {
-            var mtch = ar.match(/^([xyz][0-9]*) domain/);
+            var mtch = ar ? ar.match(/^([xyz][0-9]*) domain/) : undefined;
             if (mtch) { return mtch[1]; }
             return ar;
         }
-        var axNumMatch = shapeIn[axLetter+'ref'].match(/[xyz]([0-9]*)/);
+        var axNumMatch = (
+            shapeIn[axLetter+'ref'] ?
+            shapeIn[axLetter+'ref'].match(/[xyz]([0-9]*)/) :
+            undefined
+        );
         if (axNumMatch) {
             let axNum = axNumMatch[1];
             coerceRefExtras = coerceRefExtras.concat(
diff --git a/src/plots/cartesian/axis_ids.js b/src/plots/cartesian/axis_ids.js
index 36e622c9b7b..8b65fce5f20 100644
--- a/src/plots/cartesian/axis_ids.js
+++ b/src/plots/cartesian/axis_ids.js
@@ -83,7 +83,7 @@ exports.listIds = function(gd, axLetter) {
 exports.getFromId = function(gd, id, type) {
     var fullLayout = gd._fullLayout;
     // remove "domain" suffix
-    id = id.replace(/ *domain/,'');
+    id = (id == undefined) ? id : id.replace(/ *domain/,'');
 
     if(type === 'x') id = id.replace(/y[0-9]*/, '');
     else if(type === 'y') id = id.replace(/x[0-9]*/, '');
